@@ -1,15 +1,7 @@
 from collections.abc import Generator
 from dataclasses import dataclass
 
-from mypy.nodes import (
-    Block,
-    FuncItem,
-    IfStmt,
-    MatchStmt,
-    ReturnStmt,
-    Statement,
-    WithStmt,
-)
+from mypy.nodes import Block, FuncItem, IfStmt, MatchStmt, ReturnStmt, Statement, WithStmt
 from mypy.patterns import AsPattern
 
 from refurb.error import Error
@@ -76,7 +68,7 @@ def get_trailing_return(node: Statement) -> Generator[Statement, None, None]:
 
                 yield from get_trailing_return(body.body[-1])
 
-        case (IfStmt(else_body=Block(body=[*_, stmt])) | WithStmt(body=Block(body=[*_, stmt]))):
+        case IfStmt(else_body=Block(body=[*_, stmt])) | WithStmt(body=Block(body=[*_, stmt])):
             yield from get_trailing_return(stmt)
 
     return None
