@@ -15,7 +15,13 @@ from mypy.nodes import (
     UnaryExpr,
 )
 
-from refurb.checks.common import _stringify, slice_expr_to_slice_call, stringify
+from refurb.checks.common import (
+    _stringify,
+    get_mypy_type,
+    is_same_type,
+    slice_expr_to_slice_call,
+    stringify,
+)
 from refurb.error import Error
 
 
@@ -162,17 +168,22 @@ def check(node: FuncItem, errors: list[Error]) -> None:
                         )
                     )
 
-                case IndexExpr(
-                    base=NameExpr(name=item_name),
-                    index=index,
-                ) if item_name == name:
-                    index_expr = (
-                        slice_expr_to_slice_call(index)
-                        if isinstance(index, SliceExpr)
-                        else stringify(index)
-                    )
+                case IndexExpr(base=NameExpr() as base, index=index) if base.name == name:
+                    match index:
+                        case SliceExpr(
+                            begin_index=None,
+                            end_index=None,
+                            stride=None,
+                        ) if is_same_type(get_mypy_type(base), list):
+                            new = "list.copy"
 
-                    msg = f"Replace {func_type} with `operator.itemgetter({index_expr})`"
+                        case SliceExpr():
+                            new = f"operator.itemgetter({slice_expr_to_slice_call(index)})"
+
+                        case _:
+                            new = f"operator.itemgetter({stringify(index)})"
+
+                    msg = f"Replace {func_type} with `{new}`"
 
                     errors.append(ErrorInfo.from_node(node, msg))
 
